import requests, time
from datetime import datetime, timedelta
try: from urlparse import urlparse, parse_qs
except: from urllib.parse import urlparse, parse_qs
from ..util.sportscentral_streams import get_streams_table
from unidecode import unidecode

domain = ["sportscentral.io"]
site_name = "SportsCentral"
short_id = "SC"

def get_games():
    games = []
    current_date = datetime.now()
    date_format = current_date.strftime("%Y-%m-%d")

    leagues = ["nba", "mlb"]
    for league in leagues:
        r = requests.get("https://sportscentral.io/api/%s-tournaments?date=%s" % (league, date_format)).json()[0]
        for event in r["events"]:
            home_team = event["homeTeam"]["name"]
            home_score = event["homeScore"]["current"]
            if home_score == "": home_score = "0"
            away_team = event["awayTeam"]["name"]
            away_score = event["awayScore"]["current"]
            if away_score == "": away_score = "0"
            status = event["status"]["description"]
            title = "[COLORorange]%s %s-%s[/COLOR]: %s vs %s" % (status, home_score, away_score, home_team, away_team)
            icon = event["homeTeam"]["logo"]
            game_id = event["id"]
            game_time_str = "%sT%s" % (event["formatedStartDate"], event["startTime"])
            game_time = datetime(*(time.strptime(game_time_str, "%Y-%m-%dT%H:%M")[:6]))
            sport = event["sport"]
            links_url = "https://sportscentral.io/streams-table/%s/%s?new-ui=1&origin=mlbstreams.to" % (str(game_id), sport)
            games.append({
                "title": unidecode(title),
                "icon": icon,
                "time": game_time,
                "league": r["uniqueName"],
                "links": ["links://" + links_url]
            })
    r = requests.get("https://sportscentral.io/new-api/matches?date=" + date_format).json()
    for league in r:
        events = league["events"]
        logo = league["logo"]
        league_name = league["name"]
        for event in events:
            status = event["status"]["type"]
            if status != "inprogress": continue
            home_team = event["homeTeam"]["name"]
            home_score = event["homeScore"]["current"]
            away_team = event["awayTeam"]["name"]
            away_score = event["awayScore"]["current"]
            title = "[COLORorange]%s %s-%s[/COLOR]: %s vs %s" % (status.capitalize(), home_score, away_score, home_team, away_team)
            game_id = event["id"]
            game_time = datetime.fromtimestamp(event["startTimestamp"]) + timedelta(hours=7)
            links_url = "https://sportscentral.io/streams-table/%s/soccer?new-ui=1&origin=mlbstreams.to" % (str(game_id))
            games.append({
                "title": unidecode(title),
                "icon": unidecode(logo),
                "time": game_time,
                "league": unidecode(league_name),
                "links": ["links://" + unidecode(links_url)]
            })

    return games

def get_links(url):
    return get_streams_table(url)
